Enum DiagnosticSeverity
pub enum DiagnosticSeverity {
Note,
Remark,
Warning,
Error,
}Expand description
Severity of one user facing finding.
Declared least to most severe so the derived Ord gives the dominant
severity of a set and a >= Error filter keeps meaning.
Variants
Note
Adds context to another diagnostic.
Remark
Reports useful information about a successful operation.
Warning
Reports usable data whose semantics were defaulted, approximated, or lost.
Error
Reports invalid data or the finding that ended an operation.
Implementations
impl DiagnosticSeverity
impl DiagnosticSeverity